summaryrefslogtreecommitdiff
path: root/lib/Target/ARM/ARMBaseRegisterInfo.h
diff options
context:
space:
mode:
authorBob Wilson <bob.wilson@apple.com>2010-06-02 18:54:47 +0000
committerBob Wilson <bob.wilson@apple.com>2010-06-02 18:54:47 +0000
commit91a74da036d3a9442953ae1de3e797a50da4ccf0 (patch)
tree1bd1ac23af9b71ac5c6e35136a1c26002f71e08e /lib/Target/ARM/ARMBaseRegisterInfo.h
parent20fae651816916000c47b78843f22fd259ba4216 (diff)
downloadllvm-91a74da036d3a9442953ae1de3e797a50da4ccf0.tar.gz
llvm-91a74da036d3a9442953ae1de3e797a50da4ccf0.tar.bz2
llvm-91a74da036d3a9442953ae1de3e797a50da4ccf0.tar.xz
Rename canCombinedSubRegIndex method to something more grammatically correct
and tidy up the comment describing it. git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@105339 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/Target/ARM/ARMBaseRegisterInfo.h')
-rw-r--r--lib/Target/ARM/ARMBaseRegisterInfo.h17
1 files changed, 9 insertions, 8 deletions
diff --git a/lib/Target/ARM/ARMBaseRegisterInfo.h b/lib/Target/ARM/ARMBaseRegisterInfo.h
index 978fe4348a..c0d4e0f224 100644
--- a/lib/Target/ARM/ARMBaseRegisterInfo.h
+++ b/lib/Target/ARM/ARMBaseRegisterInfo.h
@@ -78,14 +78,15 @@ public:
getMatchingSuperRegClass(const TargetRegisterClass *A,
const TargetRegisterClass *B, unsigned Idx) const;
- /// canCombinedSubRegIndex - Given a register class and a list of sub-register
- /// indices, return true if it's possible to combine the sub-register indices
- /// into one that corresponds to a larger sub-register. Return the new sub-
- /// register index by reference. Note the new index by be zero if the given
- /// sub-registers combined to form the whole register.
- virtual bool canCombinedSubRegIndex(const TargetRegisterClass *RC,
- SmallVectorImpl<unsigned> &SubIndices,
- unsigned &NewSubIdx) const;
+ /// canCombineSubRegIndices - Given a register class and a list of
+ /// subregister indices, return true if it's possible to combine the
+ /// subregister indices into one that corresponds to a larger
+ /// subregister. Return the new subregister index by reference. Note the
+ /// new index may be zero if the given subregisters can be combined to
+ /// form the whole register.
+ virtual bool canCombineSubRegIndices(const TargetRegisterClass *RC,
+ SmallVectorImpl<unsigned> &SubIndices,
+ unsigned &NewSubIdx) const;
const TargetRegisterClass *getPointerRegClass(unsigned Kind = 0) const;